CustomUpdateDialog class abstract
Abstract interface for creating custom update dialogs.
Implement this interface to create your own beautiful update dialogs with full control over design and behavior.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context, {required bool isForceUpdate, required String appName, required VoidCallback onUpdate, required VoidCallback? onLater}) → Widget - Builds the custom update dialog widget.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited