DefaultDialogColors class
Custom colors for the default dialog.
Use this class to customize the colors of the default dialog.
Constructors
- DefaultDialogColors({Color? buttonColor, Color? textColor, Color? titleColor})
-
Creates DefaultDialogColors instance.
const
Properties
-
The color for text buttons (Later, Update Now).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textColor → Color?
-
The color for the dialog text content.
final
- titleColor → Color?
-
The color for the dialog title.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited